@@ -25,8 +25,6 @@ class Menu(MPTTModel):
     class Meta:
         verbose_name = _('Menu')
         verbose_name_plural = _('Menus')
-        app_label = _('Content')
-        db_table = 'django_zen_menu'
 
     def __unicode__(self):
         return self.name
@@ -54,8 +52,6 @@ class Page(models.Model):
     class Meta:
         verbose_name = _('Page')
         verbose_name_plural = _('Pages')
-        app_label = _('Content')
-        db_table = 'django_zen_page'
 
     def __unicode__(self):
         return self.url
